# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_iot_service.api_client import ApiClient
from dhicn_iot_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_data_add_online_processed_datas_post(self, **kwargs):  # noqa: E501
        """添加清洗数据信息 Add online processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_online_processed_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_add_online_processed_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_add_online_processed_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加清洗数据信息 Add online processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_online_processed_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ts_data_input_output'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_add_online_processed_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ts_data_input_output' in local_var_params:
            body_params = local_var_params['ts_data_input_output']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/AddOnlineProcessedDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_add_online_source_datas_post(self, **kwargs):  # noqa: E501
        """/api/Data/AddOnlineSourceDatas  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_online_source_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_add_online_source_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_add_online_source_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/Data/AddOnlineSourceDatas  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_online_source_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ts_data_input_output'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_add_online_source_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ts_data_input_output' in local_var_params:
            body_params = local_var_params['ts_data_input_output']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/AddOnlineSourceDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_add_or_update_online_processed_datas_post(self, **kwargs):  # noqa: E501
        """添加或更新清洗数据信息 Add or update processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_or_update_online_processed_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddOrUpdateOnlineDatasInput add_or_update_online_datas_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_add_or_update_online_processed_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_add_or_update_online_processed_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加或更新清洗数据信息 Add or update processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_add_or_update_online_processed_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddOrUpdateOnlineDatasInput add_or_update_online_datas_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_or_update_online_datas_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_add_or_update_online_processed_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_or_update_online_datas_input' in local_var_params:
            body_params = local_var_params['add_or_update_online_datas_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/AddOrUpdateOnlineProcessedDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_delete_online_processed_datas_post(self, **kwargs):  # noqa: E501
        """基于时间段删除清洗数据 Delete online processed data by time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_delete_online_processed_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryByTime query_by_time:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_delete_online_processed_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_delete_online_processed_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """基于时间段删除清洗数据 Delete online processed data by time  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_delete_online_processed_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryByTime query_by_time:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_by_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_delete_online_processed_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_by_time' in local_var_params:
            body_params = local_var_params['query_by_time']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/DeleteOnlineProcessedDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_get_online_processed_datas_by_conditions_post(self, **kwargs):  # noqa: E501
        """根据条件获取清洗后数据信息  Get online processed data by condition  # noqa: E501

        通过时间、点位代码、标签获取清洗后数据，如果Codes为空，则返回所有在线点位的清洗数据，如果Tag为空，则不过滤标签 Get online processed data by time or point codes. If Codes is null,then data of all the online points will be returned. If Tag is null, then tag will not be filtered.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_get_online_processed_datas_by_conditions_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetOnlineTsDataInput get_online_ts_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TsDataInputOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_get_online_processed_datas_by_conditions_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_get_online_processed_datas_by_conditions_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据条件获取清洗后数据信息  Get online processed data by condition  # noqa: E501

        通过时间、点位代码、标签获取清洗后数据，如果Codes为空，则返回所有在线点位的清洗数据，如果Tag为空，则不过滤标签 Get online processed data by time or point codes. If Codes is null,then data of all the online points will be returned. If Tag is null, then tag will not be filtered.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_get_online_processed_datas_by_conditions_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetOnlineTsDataInput get_online_ts_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TsDataInputOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_online_ts_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_get_online_processed_datas_by_conditions_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_online_ts_data_input' in local_var_params:
            body_params = local_var_params['get_online_ts_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/GetOnlineProcessedDatasByConditions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TsDataInputOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_mock_online_source_datas_get(self, **kwargs):  # noqa: E501
        """仿真在线数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_mock_online_source_datas_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str online_processed:
        :param str begin_time:
        :param str end_time:
        :param str time_span:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_mock_online_source_datas_get_with_http_info(**kwargs)  # noqa: E501

    def api_data_mock_online_source_datas_get_with_http_info(self, **kwargs):  # noqa: E501
        """仿真在线数据  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_mock_online_source_datas_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id:
        :param str online_processed:
        :param str begin_time:
        :param str end_time:
        :param str time_span:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'online_processed',
            'begin_time',
            'end_time',
            'time_span'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_mock_online_source_datas_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'online_processed' in local_var_params and local_var_params['online_processed'] is not None:  # noqa: E501
            query_params.append(('onlineProcessed', local_var_params['online_processed']))  # noqa: E501
        if 'begin_time' in local_var_params and local_var_params['begin_time'] is not None:  # noqa: E501
            query_params.append(('beginTime', local_var_params['begin_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501
        if 'time_span' in local_var_params and local_var_params['time_span'] is not None:  # noqa: E501
            query_params.append(('timeSpan', local_var_params['time_span']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/MockOnlineSourceDatas', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_modify_online_processed_datas_post(self, **kwargs):  # noqa: E501
        """/api/Data/ModifyOnlineProcessedDatas  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_modify_online_processed_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ModifyOnlineProcessedDatasInput] modify_online_processed_datas_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_modify_online_processed_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_modify_online_processed_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """/api/Data/ModifyOnlineProcessedDatas  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_modify_online_processed_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[ModifyOnlineProcessedDatasInput] modify_online_processed_datas_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'modify_online_processed_datas_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_modify_online_processed_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'modify_online_processed_datas_input' in local_var_params:
            body_params = local_var_params['modify_online_processed_datas_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/ModifyOnlineProcessedDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_update_latest_tag_post(self, **kwargs):  # noqa: E501
        """修改最新的Tag Update latest processed data tag  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_update_latest_tag_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdateLatestTagInput] update_latest_tag_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_update_latest_tag_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_update_latest_tag_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改最新的Tag Update latest processed data tag  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_update_latest_tag_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdateLatestTagInput] update_latest_tag_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_latest_tag_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_update_latest_tag_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_latest_tag_input' in local_var_params:
            body_params = local_var_params['update_latest_tag_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/UpdateLatestTag', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_data_update_online_processed_datas_post(self, **kwargs):  # noqa: E501
        """更新清洗数据信息 Update online processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_update_online_processed_datas_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_data_update_online_processed_datas_post_with_http_info(**kwargs)  # noqa: E501

    def api_data_update_online_processed_datas_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新清洗数据信息 Update online processed data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_data_update_online_processed_datas_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TsDataInputOutput] ts_data_input_output:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ts_data_input_output'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_data_update_online_processed_datas_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ts_data_input_output' in local_var_params:
            body_params = local_var_params['ts_data_input_output']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Data/UpdateOnlineProcessedDatas', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class ExecutePlcInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'execute_time': 'datetime',
        'dosing_param_setting_dtos': 'list[DosingParamSettingDto]'
    }

    attribute_map = {
        'execute_time': 'executeTime',
        'dosing_param_setting_dtos': 'dosingParamSettingDtos'
    }

    def __init__(self, execute_time=None, dosing_param_setting_dtos=None, local_vars_configuration=None):  # noqa: E501
        """ExecutePlcInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._execute_time = None
        self._dosing_param_setting_dtos = None
        self.discriminator = None

        if execute_time is not None:
            self.execute_time = execute_time
        self.dosing_param_setting_dtos = dosing_param_setting_dtos

    @property
    def execute_time(self):
        """Gets the execute_time of this ExecutePlcInput.  # noqa: E501

        执行PLC时间  # noqa: E501

        :return: The execute_time of this ExecutePlcInput.  # noqa: E501
        :rtype: datetime
        """
        return self._execute_time

    @execute_time.setter
    def execute_time(self, execute_time):
        """Sets the execute_time of this ExecutePlcInput.

        执行PLC时间  # noqa: E501

        :param execute_time: The execute_time of this ExecutePlcInput.  # noqa: E501
        :type: datetime
        """

        self._execute_time = execute_time

    @property
    def dosing_param_setting_dtos(self):
        """Gets the dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501

        加药参数  # noqa: E501

        :return: The dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501
        :rtype: list[DosingParamSettingDto]
        """
        return self._dosing_param_setting_dtos

    @dosing_param_setting_dtos.setter
    def dosing_param_setting_dtos(self, dosing_param_setting_dtos):
        """Sets the dosing_param_setting_dtos of this ExecutePlcInput.

        加药参数  # noqa: E501

        :param dosing_param_setting_dtos: The dosing_param_setting_dtos of this ExecutePlcInput.  # noqa: E501
        :type: list[DosingParamSettingDto]
        """

        self._dosing_param_setting_dtos = dosing_param_setting_dtos

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecutePlcInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExecutePlcInput):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_wwtp_data_bus_service.api.build_calc_dosage_config_api import BuildCalcDosageConfigApi
from dhicn_wwtp_data_bus_service.api.calculate_dosage_api import CalculateDosageApi
from dhicn_wwtp_data_bus_service.api.dosing_param_setting_api import DosingParamSettingApi
from dhicn_wwtp_data_bus_service.api.dosing_statistic_daily_api import DosingStatisticDailyApi
from dhicn_wwtp_data_bus_service.api.dosing_statistic_monthly_api import DosingStatisticMonthlyApi
from dhicn_wwtp_data_bus_service.api.general_data_api import GeneralDataApi
from dhicn_wwtp_data_bus_service.api.global_config_api import GlobalConfigApi
from dhicn_wwtp_data_bus_service.api.history_data_api import HistoryDataApi
from dhicn_wwtp_data_bus_service.api.import_export_api import ImportExportApi
from dhicn_wwtp_data_bus_service.api.intelligent_bus_config_api import IntelligentBusConfigApi
from dhicn_wwtp_data_bus_service.api.intelligent_denitrification_api import IntelligentDenitrificationApi
from dhicn_wwtp_data_bus_service.api.intelligent_mccr_api import IntelligentMccrApi
from dhicn_wwtp_data_bus_service.api.main_bus_config_api import MainBusConfigApi
from dhicn_wwtp_data_bus_service.api.pro_num_sim_lab_api import ProNumSimLabApi
from dhicn_wwtp_data_bus_service.api.system_setting_api import SystemSettingApi
from dhicn_wwtp_data_bus_service.api.toxicity_monitor_api import ToxicityMonitorApi
from dhicn_wwtp_data_bus_service.api.wq_analysis_api import WQAnalysisApi



# coding: utf-8

# flake8: noqa
"""
    document-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_document_service.models.add_document_model import AddDocumentModel
from dhicn_document_service.models.adding_document_model import AddingDocumentModel
from dhicn_document_service.models.adding_group_model import AddingGroupModel
from dhicn_document_service.models.copy_group_by_path_model import CopyGroupByPathModel
from dhicn_document_service.models.copy_group_model import CopyGroupModel
from dhicn_document_service.models.document import Document
from dhicn_document_service.models.document_adding_item_model import DocumentAddingItemModel
from dhicn_document_service.models.document_group_item import DocumentGroupItem
from dhicn_document_service.models.group import Group
from dhicn_document_service.models.http_content import HttpContent
from dhicn_document_service.models.http_method import HttpMethod
from dhicn_document_service.models.http_request_message import HttpRequestMessage
from dhicn_document_service.models.http_response_message import HttpResponseMessage
from dhicn_document_service.models.http_status_code import HttpStatusCode
from dhicn_document_service.models.http_version_policy import HttpVersionPolicy
from dhicn_document_service.models.move_group_by_path_model import MoveGroupByPathModel
from dhicn_document_service.models.move_group_model import MoveGroupModel
from dhicn_document_service.models.renaming_group_model import RenamingGroupModel
from dhicn_document_service.models.string_string_i_enumerable_key_value_pair import StringStringIEnumerableKeyValuePair
from dhicn_document_service.models.version import Version



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class NtsGeometryServices(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'geometry_overlay': 'object',
        'coordinate_equality_comparer': 'object',
        'default_srid': 'int',
        'default_coordinate_sequence_factory': 'CoordinateSequenceFactory',
        'default_precision_model': 'PrecisionModel'
    }

    attribute_map = {
        'geometry_overlay': 'geometryOverlay',
        'coordinate_equality_comparer': 'coordinateEqualityComparer',
        'default_srid': 'defaultSRID',
        'default_coordinate_sequence_factory': 'defaultCoordinateSequenceFactory',
        'default_precision_model': 'defaultPrecisionModel'
    }

    def __init__(self, geometry_overlay=None, coordinate_equality_comparer=None, default_srid=None, default_coordinate_sequence_factory=None, default_precision_model=None, local_vars_configuration=None):  # noqa: E501
        """NtsGeometryServices - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._geometry_overlay = None
        self._coordinate_equality_comparer = None
        self._default_srid = None
        self._default_coordinate_sequence_factory = None
        self._default_precision_model = None
        self.discriminator = None

        if geometry_overlay is not None:
            self.geometry_overlay = geometry_overlay
        if coordinate_equality_comparer is not None:
            self.coordinate_equality_comparer = coordinate_equality_comparer
        if default_srid is not None:
            self.default_srid = default_srid
        if default_coordinate_sequence_factory is not None:
            self.default_coordinate_sequence_factory = default_coordinate_sequence_factory
        if default_precision_model is not None:
            self.default_precision_model = default_precision_model

    @property
    def geometry_overlay(self):
        """Gets the geometry_overlay of this NtsGeometryServices.  # noqa: E501


        :return: The geometry_overlay of this NtsGeometryServices.  # noqa: E501
        :rtype: object
        """
        return self._geometry_overlay

    @geometry_overlay.setter
    def geometry_overlay(self, geometry_overlay):
        """Sets the geometry_overlay of this NtsGeometryServices.


        :param geometry_overlay: The geometry_overlay of this NtsGeometryServices.  # noqa: E501
        :type: object
        """

        self._geometry_overlay = geometry_overlay

    @property
    def coordinate_equality_comparer(self):
        """Gets the coordinate_equality_comparer of this NtsGeometryServices.  # noqa: E501


        :return: The coordinate_equality_comparer of this NtsGeometryServices.  # noqa: E501
        :rtype: object
        """
        return self._coordinate_equality_comparer

    @coordinate_equality_comparer.setter
    def coordinate_equality_comparer(self, coordinate_equality_comparer):
        """Sets the coordinate_equality_comparer of this NtsGeometryServices.


        :param coordinate_equality_comparer: The coordinate_equality_comparer of this NtsGeometryServices.  # noqa: E501
        :type: object
        """

        self._coordinate_equality_comparer = coordinate_equality_comparer

    @property
    def default_srid(self):
        """Gets the default_srid of this NtsGeometryServices.  # noqa: E501


        :return: The default_srid of this NtsGeometryServices.  # noqa: E501
        :rtype: int
        """
        return self._default_srid

    @default_srid.setter
    def default_srid(self, default_srid):
        """Sets the default_srid of this NtsGeometryServices.


        :param default_srid: The default_srid of this NtsGeometryServices.  # noqa: E501
        :type: int
        """

        self._default_srid = default_srid

    @property
    def default_coordinate_sequence_factory(self):
        """Gets the default_coordinate_sequence_factory of this NtsGeometryServices.  # noqa: E501


        :return: The default_coordinate_sequence_factory of this NtsGeometryServices.  # noqa: E501
        :rtype: CoordinateSequenceFactory
        """
        return self._default_coordinate_sequence_factory

    @default_coordinate_sequence_factory.setter
    def default_coordinate_sequence_factory(self, default_coordinate_sequence_factory):
        """Sets the default_coordinate_sequence_factory of this NtsGeometryServices.


        :param default_coordinate_sequence_factory: The default_coordinate_sequence_factory of this NtsGeometryServices.  # noqa: E501
        :type: CoordinateSequenceFactory
        """

        self._default_coordinate_sequence_factory = default_coordinate_sequence_factory

    @property
    def default_precision_model(self):
        """Gets the default_precision_model of this NtsGeometryServices.  # noqa: E501


        :return: The default_precision_model of this NtsGeometryServices.  # noqa: E501
        :rtype: PrecisionModel
        """
        return self._default_precision_model

    @default_precision_model.setter
    def default_precision_model(self, default_precision_model):
        """Sets the default_precision_model of this NtsGeometryServices.


        :param default_precision_model: The default_precision_model of this NtsGeometryServices.  # noqa: E501
        :type: PrecisionModel
        """

        self._default_precision_model = default_precision_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NtsGeometryServices):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NtsGeometryServices):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class UpdateAssetInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'type': 'str',
        'label': 'str',
        'description': 'str',
        'attributes': 'list[StringStringKeyValue]',
        'id': 'str',
        'created_time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'label': 'label',
        'description': 'description',
        'attributes': 'attributes',
        'id': 'id',
        'created_time': 'createdTime'
    }

    def __init__(self, name=None, type=None, label=None, description=None, attributes=None, id=None, created_time=None, local_vars_configuration=None):  # noqa: E501
        """UpdateAssetInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._type = None
        self._label = None
        self._description = None
        self._attributes = None
        self._id = None
        self._created_time = None
        self.discriminator = None

        self.name = name
        self.type = type
        self.label = label
        self.description = description
        self.attributes = attributes
        self.id = id
        if created_time is not None:
            self.created_time = created_time

    @property
    def name(self):
        """Gets the name of this UpdateAssetInput.  # noqa: E501

        资产名称 asset name  # noqa: E501

        :return: The name of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateAssetInput.

        资产名称 asset name  # noqa: E501

        :param name: The name of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this UpdateAssetInput.  # noqa: E501

        资产类型（自定义） asset type (customized)  # noqa: E501

        :return: The type of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateAssetInput.

        资产类型（自定义） asset type (customized)  # noqa: E501

        :param type: The type of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def label(self):
        """Gets the label of this UpdateAssetInput.  # noqa: E501

        资产标签 asset label  # noqa: E501

        :return: The label of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this UpdateAssetInput.

        资产标签 asset label  # noqa: E501

        :param label: The label of this UpdateAssetInput.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def description(self):
        """Gets the description of this UpdateAssetInput.  # noqa: E501

        资产描述 asset description  # noqa: E501

        :return: The description of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this UpdateAssetInput.

        资产描述 asset description  # noqa: E501

        :param description: The description of this UpdateAssetInput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def attributes(self):
        """Gets the attributes of this UpdateAssetInput.  # noqa: E501

        资产自定义属性 asset customized attributes  # noqa: E501

        :return: The attributes of this UpdateAssetInput.  # noqa: E501
        :rtype: list[StringStringKeyValue]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this UpdateAssetInput.

        资产自定义属性 asset customized attributes  # noqa: E501

        :param attributes: The attributes of this UpdateAssetInput.  # noqa: E501
        :type: list[StringStringKeyValue]
        """

        self._attributes = attributes

    @property
    def id(self):
        """Gets the id of this UpdateAssetInput.  # noqa: E501

        资产Id asset Id  # noqa: E501

        :return: The id of this UpdateAssetInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UpdateAssetInput.

        资产Id asset Id  # noqa: E501

        :param id: The id of this UpdateAssetInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this UpdateAssetInput.  # noqa: E501

        创建时间 asset createtion time  # noqa: E501

        :return: The created_time of this UpdateAssetInput.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this UpdateAssetInput.

        创建时间 asset createtion time  # noqa: E501

        :param created_time: The created_time of this UpdateAssetInput.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAssetInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateAssetInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    accident-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_accident_management_service.api_client import ApiClient
from dhicn_accident_management_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AccidentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_accident_accident_add_accident_post(self, **kwargs):  # noqa: E501
        """批量添加事故详细信息 Batch add accidents with detailed information  # noqa: E501

        批量添加事故详细信息，包括关联的情景、事件、污染物等信息 Batch add accidents with detailed information including subordinate scenes, events, pollutants, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_add_accident_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccidentDetailInput accident_detail_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_add_accident_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_add_accident_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量添加事故详细信息 Batch add accidents with detailed information  # noqa: E501

        批量添加事故详细信息，包括关联的情景、事件、污染物等信息 Batch add accidents with detailed information including subordinate scenes, events, pollutants, etc.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_add_accident_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AccidentDetailInput accident_detail_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'accident_detail_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_add_accident_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'accident_detail_input' in local_var_params:
            body_params = local_var_params['accident_detail_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/add-accident', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_accident_accident_add_post(self, **kwargs):  # noqa: E501
        """添加一个事故信息 Add an accident  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddAccidentInput add_accident_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AccidentInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加一个事故信息 Add an accident  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddAccidentInput add_accident_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AccidentInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_accident_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_accident_input' in local_var_params:
            body_params = local_var_params['add_accident_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccidentInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_accident_accident_delete_post(self, **kwargs):  # noqa: E501
        """根据ID删除事故信息 Delete accidents by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID删除事故信息 Delete accidents by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_accident_accident_detail_get(self, **kwargs):  # noqa: E501
        """根据ID查询事故信息 Get accident by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_detail_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str accident_id: 事故ID accident id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AccidentDetailInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_detail_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_detail_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID查询事故信息 Get accident by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_detail_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str accident_id: 事故ID accident id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AccidentDetailInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'accident_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_detail_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'accident_id' in local_var_params and local_var_params['accident_id'] is not None:  # noqa: E501
            query_params.append(('accidentId', local_var_params['accident_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/detail', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccidentDetailInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_accident_accident_list_get(self, **kwargs):  # noqa: E501
        """根据事故名称、等级、类型查询事故信息 Query accidents by accident name, level and type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_list_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: 事故名称 accident name
        :param str accident_level: 事故等级 accident level
        :param str accident_type: 事故类型 accident type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AccidentInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_list_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_list_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据事故名称、等级、类型查询事故信息 Query accidents by accident name, level and type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_list_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: 事故名称 accident name
        :param str accident_level: 事故等级 accident level
        :param str accident_type: 事故类型 accident type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AccidentInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'accident_level',
            'accident_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_list_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('Name', local_var_params['name']))  # noqa: E501
        if 'accident_level' in local_var_params and local_var_params['accident_level'] is not None:  # noqa: E501
            query_params.append(('AccidentLevel', local_var_params['accident_level']))  # noqa: E501
        if 'accident_type' in local_var_params and local_var_params['accident_type'] is not None:  # noqa: E501
            query_params.append(('AccidentType', local_var_params['accident_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/list', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AccidentInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_accident_accident_update_post(self, **kwargs):  # noqa: E501
        """更新事故信息 Update an accident  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateAccidentInput update_accident_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AccidentInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_accident_accident_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_accident_accident_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新事故信息 Update an accident  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_accident_accident_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateAccidentInput update_accident_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AccidentInfo, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_accident_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_accident_accident_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_accident_input' in local_var_params:
            body_params = local_var_params['update_accident_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/accident/accident/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AccidentInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class ModelBoundaryConfigInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'model_point_id': 'str',
        'show_name': 'str',
        'dfs0_file': 'str',
        'data_item': 'str',
        'point_json': 'list[BoundaryConfigPointItem]',
        'measure_expression': 'PointExpressItem',
        'forecast_expression': 'PointExpressItem',
        'template_id': 'str',
        'boundary_id': 'str',
        'boundary_type': 'int',
        'data_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'model_point_id': 'modelPointId',
        'show_name': 'showName',
        'dfs0_file': 'dfs0File',
        'data_item': 'dataItem',
        'point_json': 'pointJson',
        'measure_expression': 'measureExpression',
        'forecast_expression': 'forecastExpression',
        'template_id': 'templateId',
        'boundary_id': 'boundaryId',
        'boundary_type': 'boundaryType',
        'data_type': 'dataType'
    }

    def __init__(self, id=None, model_point_id=None, show_name=None, dfs0_file=None, data_item=None, point_json=None, measure_expression=None, forecast_expression=None, template_id=None, boundary_id=None, boundary_type=None, data_type=None, local_vars_configuration=None):  # noqa: E501
        """ModelBoundaryConfigInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._model_point_id = None
        self._show_name = None
        self._dfs0_file = None
        self._data_item = None
        self._point_json = None
        self._measure_expression = None
        self._forecast_expression = None
        self._template_id = None
        self._boundary_id = None
        self._boundary_type = None
        self._data_type = None
        self.discriminator = None

        self.id = id
        if model_point_id is not None:
            self.model_point_id = model_point_id
        self.show_name = show_name
        self.dfs0_file = dfs0_file
        self.data_item = data_item
        self.point_json = point_json
        if measure_expression is not None:
            self.measure_expression = measure_expression
        if forecast_expression is not None:
            self.forecast_expression = forecast_expression
        if template_id is not None:
            self.template_id = template_id
        self.boundary_id = boundary_id
        if boundary_type is not None:
            self.boundary_type = boundary_type
        self.data_type = data_type

    @property
    def id(self):
        """Gets the id of this ModelBoundaryConfigInput.  # noqa: E501

        配置项ID configuration id  # noqa: E501

        :return: The id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelBoundaryConfigInput.

        配置项ID configuration id  # noqa: E501

        :param id: The id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_point_id(self):
        """Gets the model_point_id of this ModelBoundaryConfigInput.  # noqa: E501

        模型点位ID model point id  # noqa: E501

        :return: The model_point_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_id

    @model_point_id.setter
    def model_point_id(self, model_point_id):
        """Sets the model_point_id of this ModelBoundaryConfigInput.

        模型点位ID model point id  # noqa: E501

        :param model_point_id: The model_point_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._model_point_id = model_point_id

    @property
    def show_name(self):
        """Gets the show_name of this ModelBoundaryConfigInput.  # noqa: E501

        边界显示名称 boundary show name  # noqa: E501

        :return: The show_name of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this ModelBoundaryConfigInput.

        边界显示名称 boundary show name  # noqa: E501

        :param show_name: The show_name of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def dfs0_file(self):
        """Gets the dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501

        边界时间序列数据dfs0文件的相对路径 Dfs0 file path  # noqa: E501

        :return: The dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._dfs0_file

    @dfs0_file.setter
    def dfs0_file(self, dfs0_file):
        """Sets the dfs0_file of this ModelBoundaryConfigInput.

        边界时间序列数据dfs0文件的相对路径 Dfs0 file path  # noqa: E501

        :param dfs0_file: The dfs0_file of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._dfs0_file = dfs0_file

    @property
    def data_item(self):
        """Gets the data_item of this ModelBoundaryConfigInput.  # noqa: E501

        边界时间序列数据Dfs0文件中的数据项名称 Dfs0 data item  # noqa: E501

        :return: The data_item of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._data_item

    @data_item.setter
    def data_item(self, data_item):
        """Sets the data_item of this ModelBoundaryConfigInput.

        边界时间序列数据Dfs0文件中的数据项名称 Dfs0 data item  # noqa: E501

        :param data_item: The data_item of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._data_item = data_item

    @property
    def point_json(self):
        """Gets the point_json of this ModelBoundaryConfigInput.  # noqa: E501

        对应的设备指标信息 corresponding device indicators  # noqa: E501

        :return: The point_json of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: list[BoundaryConfigPointItem]
        """
        return self._point_json

    @point_json.setter
    def point_json(self, point_json):
        """Sets the point_json of this ModelBoundaryConfigInput.

        对应的设备指标信息 corresponding device indicators  # noqa: E501

        :param point_json: The point_json of this ModelBoundaryConfigInput.  # noqa: E501
        :type: list[BoundaryConfigPointItem]
        """

        self._point_json = point_json

    @property
    def measure_expression(self):
        """Gets the measure_expression of this ModelBoundaryConfigInput.  # noqa: E501


        :return: The measure_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: PointExpressItem
        """
        return self._measure_expression

    @measure_expression.setter
    def measure_expression(self, measure_expression):
        """Sets the measure_expression of this ModelBoundaryConfigInput.


        :param measure_expression: The measure_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :type: PointExpressItem
        """

        self._measure_expression = measure_expression

    @property
    def forecast_expression(self):
        """Gets the forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501


        :return: The forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: PointExpressItem
        """
        return self._forecast_expression

    @forecast_expression.setter
    def forecast_expression(self, forecast_expression):
        """Sets the forecast_expression of this ModelBoundaryConfigInput.


        :param forecast_expression: The forecast_expression of this ModelBoundaryConfigInput.  # noqa: E501
        :type: PointExpressItem
        """

        self._forecast_expression = forecast_expression

    @property
    def template_id(self):
        """Gets the template_id of this ModelBoundaryConfigInput.  # noqa: E501

        模板方案Id template scenario id  # noqa: E501

        :return: The template_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this ModelBoundaryConfigInput.

        模板方案Id template scenario id  # noqa: E501

        :param template_id: The template_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def boundary_id(self):
        """Gets the boundary_id of this ModelBoundaryConfigInput.  # noqa: E501

        模型边界ID boundary id  # noqa: E501

        :return: The boundary_id of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._boundary_id

    @boundary_id.setter
    def boundary_id(self, boundary_id):
        """Sets the boundary_id of this ModelBoundaryConfigInput.

        模型边界ID boundary id  # noqa: E501

        :param boundary_id: The boundary_id of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._boundary_id = boundary_id

    @property
    def boundary_type(self):
        """Gets the boundary_type of this ModelBoundaryConfigInput.  # noqa: E501

        1-Rainfall 2-Air_Temperature 3-Evapo_Transpiration 4-Catchment_discharge 5-Catchment_discharge_per_area 6-Catchment_discharge_per_PE 7-Load_point_discharge 8-Load_point_discharge_per_unit 9-Inflow_to_Node 10-Inflow_to_Link 11-Inflow_from_Result_File 12-Outlet_Water_Level 13-Exfiltration_from_node 14-Exfiltration_from_link 15-StormWater_load_surface 16-StormWater_load_RDII 17-Open_Inflow_To_River 18-Source_Inflow_To_River 19-River_Water_Level 20-River_QH_Relation 21-Free_River_Outflow 22-Closed_River_Boundary 30-CS_Pump 31-CS_Valve 32-River_Pump 33-River_Gate 41-Pollutant_concentration 42-Pollutant_load 43-Sediment_concentration 44-Sediment_load 45-Microorganisms 46-Temperature 47-Salinity 48-PH 49-Wate_Age 50-Wate_Blend 51-WD_Pattern 52-WD_Curve 53-WD_Pump 54-WD_Valve 999-Other -1-Undefined   # noqa: E501

        :return: The boundary_type of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: int
        """
        return self._boundary_type

    @boundary_type.setter
    def boundary_type(self, boundary_type):
        """Sets the boundary_type of this ModelBoundaryConfigInput.

        1-Rainfall 2-Air_Temperature 3-Evapo_Transpiration 4-Catchment_discharge 5-Catchment_discharge_per_area 6-Catchment_discharge_per_PE 7-Load_point_discharge 8-Load_point_discharge_per_unit 9-Inflow_to_Node 10-Inflow_to_Link 11-Inflow_from_Result_File 12-Outlet_Water_Level 13-Exfiltration_from_node 14-Exfiltration_from_link 15-StormWater_load_surface 16-StormWater_load_RDII 17-Open_Inflow_To_River 18-Source_Inflow_To_River 19-River_Water_Level 20-River_QH_Relation 21-Free_River_Outflow 22-Closed_River_Boundary 30-CS_Pump 31-CS_Valve 32-River_Pump 33-River_Gate 41-Pollutant_concentration 42-Pollutant_load 43-Sediment_concentration 44-Sediment_load 45-Microorganisms 46-Temperature 47-Salinity 48-PH 49-Wate_Age 50-Wate_Blend 51-WD_Pattern 52-WD_Curve 53-WD_Pump 54-WD_Valve 999-Other -1-Undefined   # noqa: E501

        :param boundary_type: The boundary_type of this ModelBoundaryConfigInput.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 30, 31, 32, 33, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 999, -1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and boundary_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `boundary_type` ({0}), must be one of {1}"  # noqa: E501
                .format(boundary_type, allowed_values)
            )

        self._boundary_type = boundary_type

    @property
    def data_type(self):
        """Gets the data_type of this ModelBoundaryConfigInput.  # noqa: E501

        数据类型（主要针对结构物） data type, mainly for structures  # noqa: E501

        :return: The data_type of this ModelBoundaryConfigInput.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ModelBoundaryConfigInput.

        数据类型（主要针对结构物） data type, mainly for structures  # noqa: E501

        :param data_type: The data_type of this ModelBoundaryConfigInput.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelBoundaryConfigInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelBoundaryConfigInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class CurrentOnlineModelData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'current_time': 'datetime',
        'measure_data': 'float',
        'model_data': 'float'
    }

    attribute_map = {
        'id': 'id',
        'current_time': 'currentTime',
        'measure_data': 'measureData',
        'model_data': 'modelData'
    }

    def __init__(self, id=None, current_time=None, measure_data=None, model_data=None, local_vars_configuration=None):  # noqa: E501
        """CurrentOnlineModelData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._current_time = None
        self._measure_data = None
        self._model_data = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if current_time is not None:
            self.current_time = current_time
        if measure_data is not None:
            self.measure_data = measure_data
        if model_data is not None:
            self.model_data = model_data

    @property
    def id(self):
        """Gets the id of this CurrentOnlineModelData.  # noqa: E501

        指标id  # noqa: E501

        :return: The id of this CurrentOnlineModelData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CurrentOnlineModelData.

        指标id  # noqa: E501

        :param id: The id of this CurrentOnlineModelData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def current_time(self):
        """Gets the current_time of this CurrentOnlineModelData.  # noqa: E501

        最新实测和模拟时间  # noqa: E501

        :return: The current_time of this CurrentOnlineModelData.  # noqa: E501
        :rtype: datetime
        """
        return self._current_time

    @current_time.setter
    def current_time(self, current_time):
        """Sets the current_time of this CurrentOnlineModelData.

        最新实测和模拟时间  # noqa: E501

        :param current_time: The current_time of this CurrentOnlineModelData.  # noqa: E501
        :type: datetime
        """

        self._current_time = current_time

    @property
    def measure_data(self):
        """Gets the measure_data of this CurrentOnlineModelData.  # noqa: E501

        最新指标点位实测值  # noqa: E501

        :return: The measure_data of this CurrentOnlineModelData.  # noqa: E501
        :rtype: float
        """
        return self._measure_data

    @measure_data.setter
    def measure_data(self, measure_data):
        """Sets the measure_data of this CurrentOnlineModelData.

        最新指标点位实测值  # noqa: E501

        :param measure_data: The measure_data of this CurrentOnlineModelData.  # noqa: E501
        :type: float
        """

        self._measure_data = measure_data

    @property
    def model_data(self):
        """Gets the model_data of this CurrentOnlineModelData.  # noqa: E501

        最新点位结果时序值  # noqa: E501

        :return: The model_data of this CurrentOnlineModelData.  # noqa: E501
        :rtype: float
        """
        return self._model_data

    @model_data.setter
    def model_data(self, model_data):
        """Sets the model_data of this CurrentOnlineModelData.

        最新点位结果时序值  # noqa: E501

        :param model_data: The model_data of this CurrentOnlineModelData.  # noqa: E501
        :type: float
        """

        self._model_data = model_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CurrentOnlineModelData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CurrentOnlineModelData):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_iot_service.api.asset_api import AssetApi
from dhicn_iot_service.api.auth_api import AuthApi
from dhicn_iot_service.api.data_api import DataApi
from dhicn_iot_service.api.device_api import DeviceApi
from dhicn_iot_service.api.device_maintenance_api import DeviceMaintenanceApi
from dhicn_iot_service.api.historical_data_search_api import HistoricalDataSearchApi
from dhicn_iot_service.api.integration_api import IntegrationApi
from dhicn_iot_service.api.iot_group_api import IotGroupApi
from dhicn_iot_service.api.net_request_api import NetRequestApi
from dhicn_iot_service.api.notify_api import NotifyApi
from dhicn_iot_service.api.opcua_api import OpcuaApi
from dhicn_iot_service.api.telemetry_api import TelemetryApi
from dhicn_iot_service.api.telemetry_mock_data_api import TelemetryMockDataApi



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_model_driver_service.api.health_api import HealthApi
from dhicn_model_driver_service.api.model_run_api import ModelRunApi



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class OpcUaComAssemblyInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'device_name': 'str',
        'indicator': 'str',
        'indicator_id': 'str',
        'node_name': 'str',
        'node': 'str',
        'unit': 'str',
        'data_type': 'str',
        'decimal_places': 'int',
        'time_processing_mode': 'int',
        'is_open_sync': 'bool',
        'period': 'int',
        'opc_flag': 'str',
        'syn_freq': 'str'
    }

    attribute_map = {
        'id': 'id',
        'device_name': 'deviceName',
        'indicator': 'indicator',
        'indicator_id': 'indicatorId',
        'node_name': 'nodeName',
        'node': 'node',
        'unit': 'unit',
        'data_type': 'dataType',
        'decimal_places': 'decimalPlaces',
        'time_processing_mode': 'timeProcessingMode',
        'is_open_sync': 'isOpenSync',
        'period': 'period',
        'opc_flag': 'opcFlag',
        'syn_freq': 'synFreq'
    }

    def __init__(self, id=None, device_name=None, indicator=None, indicator_id=None, node_name=None, node=None, unit=None, data_type=None, decimal_places=None, time_processing_mode=None, is_open_sync=None, period=None, opc_flag=None, syn_freq=None, local_vars_configuration=None):  # noqa: E501
        """OpcUaComAssemblyInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._device_name = None
        self._indicator = None
        self._indicator_id = None
        self._node_name = None
        self._node = None
        self._unit = None
        self._data_type = None
        self._decimal_places = None
        self._time_processing_mode = None
        self._is_open_sync = None
        self._period = None
        self._opc_flag = None
        self._syn_freq = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.device_name = device_name
        self.indicator = indicator
        if indicator_id is not None:
            self.indicator_id = indicator_id
        self.node_name = node_name
        self.node = node
        self.unit = unit
        self.data_type = data_type
        if decimal_places is not None:
            self.decimal_places = decimal_places
        self.time_processing_mode = time_processing_mode
        self.is_open_sync = is_open_sync
        self.period = period
        self.opc_flag = opc_flag
        self.syn_freq = syn_freq

    @property
    def id(self):
        """Gets the id of this OpcUaComAssemblyInfo.  # noqa: E501

        Id Id  # noqa: E501

        :return: The id of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OpcUaComAssemblyInfo.

        Id Id  # noqa: E501

        :param id: The id of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def device_name(self):
        """Gets the device_name of this OpcUaComAssemblyInfo.  # noqa: E501

        设备名称  # noqa: E501

        :return: The device_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this OpcUaComAssemblyInfo.

        设备名称  # noqa: E501

        :param device_name: The device_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def indicator(self):
        """Gets the indicator of this OpcUaComAssemblyInfo.  # noqa: E501

        指标  # noqa: E501

        :return: The indicator of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this OpcUaComAssemblyInfo.

        指标  # noqa: E501

        :param indicator: The indicator of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def indicator_id(self):
        """Gets the indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501

        设备指标Id，对应着设备-指标 device indicator id  # noqa: E501

        :return: The indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._indicator_id

    @indicator_id.setter
    def indicator_id(self, indicator_id):
        """Sets the indicator_id of this OpcUaComAssemblyInfo.

        设备指标Id，对应着设备-指标 device indicator id  # noqa: E501

        :param indicator_id: The indicator_id of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._indicator_id = indicator_id

    @property
    def node_name(self):
        """Gets the node_name of this OpcUaComAssemblyInfo.  # noqa: E501

        节点名称，如:主线静压式液位 node name  # noqa: E501

        :return: The node_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this OpcUaComAssemblyInfo.

        节点名称，如:主线静压式液位 node name  # noqa: E501

        :param node_name: The node_name of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def node(self):
        """Gets the node of this OpcUaComAssemblyInfo.  # noqa: E501

        节点检测项 node detection item  # noqa: E501

        :return: The node of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this OpcUaComAssemblyInfo.

        节点检测项 node detection item  # noqa: E501

        :param node: The node of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def unit(self):
        """Gets the unit of this OpcUaComAssemblyInfo.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this OpcUaComAssemblyInfo.

        单位 unit  # noqa: E501

        :param unit: The unit of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def data_type(self):
        """Gets the data_type of this OpcUaComAssemblyInfo.  # noqa: E501

        数据类型,BoolValue/DateTimeValue/DblValue/LongValue/StrValue data type: BoolValue/DateTimeValue/DblValue/LongValue/StrValue  # noqa: E501

        :return: The data_type of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this OpcUaComAssemblyInfo.

        数据类型,BoolValue/DateTimeValue/DblValue/LongValue/StrValue data type: BoolValue/DateTimeValue/DblValue/LongValue/StrValue  # noqa: E501

        :param data_type: The data_type of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def decimal_places(self):
        """Gets the decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501

        小数点数 decimal places  # noqa: E501

        :return: The decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._decimal_places

    @decimal_places.setter
    def decimal_places(self, decimal_places):
        """Sets the decimal_places of this OpcUaComAssemblyInfo.

        小数点数 decimal places  # noqa: E501

        :param decimal_places: The decimal_places of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """

        self._decimal_places = decimal_places

    @property
    def time_processing_mode(self):
        """Gets the time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501

        时间处理模式,枚举：second秒、minute分、hour小时、original(默认原始值,不做处理)  # noqa: E501

        :return: The time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._time_processing_mode

    @time_processing_mode.setter
    def time_processing_mode(self, time_processing_mode):
        """Sets the time_processing_mode of this OpcUaComAssemblyInfo.

        时间处理模式,枚举：second秒、minute分、hour小时、original(默认原始值,不做处理)  # noqa: E501

        :param time_processing_mode: The time_processing_mode of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [None,0, 1, 2, 3]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and time_processing_mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `time_processing_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(time_processing_mode, allowed_values)
            )

        self._time_processing_mode = time_processing_mode

    @property
    def is_open_sync(self):
        """Gets the is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501

        是否启用同步 Is open sync,  # noqa: E501

        :return: The is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_open_sync

    @is_open_sync.setter
    def is_open_sync(self, is_open_sync):
        """Sets the is_open_sync of this OpcUaComAssemblyInfo.

        是否启用同步 Is open sync,  # noqa: E501

        :param is_open_sync: The is_open_sync of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: bool
        """

        self._is_open_sync = is_open_sync

    @property
    def period(self):
        """Gets the period of this OpcUaComAssemblyInfo.  # noqa: E501

        时间步长  # noqa: E501

        :return: The period of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this OpcUaComAssemblyInfo.

        时间步长  # noqa: E501

        :param period: The period of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def opc_flag(self):
        """Gets the opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501

        标识，OpcUaConfig表的OpcFlag  # noqa: E501

        :return: The opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._opc_flag

    @opc_flag.setter
    def opc_flag(self, opc_flag):
        """Sets the opc_flag of this OpcUaComAssemblyInfo.

        标识，OpcUaConfig表的OpcFlag  # noqa: E501

        :param opc_flag: The opc_flag of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._opc_flag = opc_flag

    @property
    def syn_freq(self):
        """Gets the syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501

        同步频率，例如：30s/5m/1h  # noqa: E501

        :return: The syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501
        :rtype: str
        """
        return self._syn_freq

    @syn_freq.setter
    def syn_freq(self, syn_freq):
        """Sets the syn_freq of this OpcUaComAssemblyInfo.

        同步频率，例如：30s/5m/1h  # noqa: E501

        :param syn_freq: The syn_freq of this OpcUaComAssemblyInfo.  # noqa: E501
        :type: str
        """

        self._syn_freq = syn_freq

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OpcUaComAssemblyInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OpcUaComAssemblyInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class GetOnlineTsDataInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'start_time': 'datetime',
        'end_time': 'datetime',
        'codes': 'list[str]',
        'tag': 'str'
    }

    attribute_map = {
        'start_time': 'startTime',
        'end_time': 'endTime',
        'codes': 'codes',
        'tag': 'tag'
    }

    def __init__(self, start_time=None, end_time=None, codes=None, tag=None, local_vars_configuration=None):  # noqa: E501
        """GetOnlineTsDataInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._start_time = None
        self._end_time = None
        self._codes = None
        self._tag = None
        self.discriminator = None

        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        self.codes = codes
        self.tag = tag

    @property
    def start_time(self):
        """Gets the start_time of this GetOnlineTsDataInput.  # noqa: E501

        开始时间 start time  # noqa: E501

        :return: The start_time of this GetOnlineTsDataInput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this GetOnlineTsDataInput.

        开始时间 start time  # noqa: E501

        :param start_time: The start_time of this GetOnlineTsDataInput.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this GetOnlineTsDataInput.  # noqa: E501

        结束时间 end time  # noqa: E501

        :return: The end_time of this GetOnlineTsDataInput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this GetOnlineTsDataInput.

        结束时间 end time  # noqa: E501

        :param end_time: The end_time of this GetOnlineTsDataInput.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def codes(self):
        """Gets the codes of this GetOnlineTsDataInput.  # noqa: E501

        在线点位代码或者模型点位代码 online point code or model node code  # noqa: E501

        :return: The codes of this GetOnlineTsDataInput.  # noqa: E501
        :rtype: list[str]
        """
        return self._codes

    @codes.setter
    def codes(self, codes):
        """Sets the codes of this GetOnlineTsDataInput.

        在线点位代码或者模型点位代码 online point code or model node code  # noqa: E501

        :param codes: The codes of this GetOnlineTsDataInput.  # noqa: E501
        :type: list[str]
        """

        self._codes = codes

    @property
    def tag(self):
        """Gets the tag of this GetOnlineTsDataInput.  # noqa: E501

        数据清洗标签 clean tag  # noqa: E501

        :return: The tag of this GetOnlineTsDataInput.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this GetOnlineTsDataInput.

        数据清洗标签 clean tag  # noqa: E501

        :param tag: The tag of this GetOnlineTsDataInput.  # noqa: E501
        :type: str
        """

        self._tag = tag

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetOnlineTsDataInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetOnlineTsDataInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    domian-paas-sdk-python
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "dhicn_domain_paas_sdk_python"
VERSION = "1.0.12"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
# with open('README.md', encoding='utf-8') as f:
#     readme = f.read()

setup(
    name=NAME,
    version=VERSION,
    author="dhi",
    author_email="wafe@dhigroup.com",
    url="https://github.com/DHICN/Domain-Paas-SDK-Python",
    keywords=["sdk", "python", "domain-paas"],
    install_requires=REQUIRES,
    packages=find_packages(where='src',exclude=["test", "tests"]),
    include_package_data=True,
    long_description="这是一个[DHI 中国 业务中台](https://online-products.dhichina.cn/) 的 Client SDK 开发辅助包，帮您快速通过我们的业务中台构建应用。",
    package_dir={'':'src'},
    license='MIT'
)



# coding: utf-8

"""
    document-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_document_service.configuration import Configuration


class HttpStatusCode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    _100 = "100"
    _101 = "101"
    _102 = "102"
    _103 = "103"
    _200 = "200"
    _201 = "201"
    _202 = "202"
    _203 = "203"
    _204 = "204"
    _205 = "205"
    _206 = "206"
    _207 = "207"
    _208 = "208"
    _226 = "226"
    _300 = "300"
    _301 = "301"
    _302 = "302"
    _303 = "303"
    _304 = "304"
    _305 = "305"
    _306 = "306"
    _307 = "307"
    _308 = "308"
    _400 = "400"
    _401 = "401"
    _402 = "402"
    _403 = "403"
    _404 = "404"
    _405 = "405"
    _406 = "406"
    _407 = "407"
    _408 = "408"
    _409 = "409"
    _410 = "410"
    _411 = "411"
    _412 = "412"
    _413 = "413"
    _414 = "414"
    _415 = "415"
    _416 = "416"
    _417 = "417"
    _421 = "421"
    _422 = "422"
    _423 = "423"
    _424 = "424"
    _426 = "426"
    _428 = "428"
    _429 = "429"
    _431 = "431"
    _451 = "451"
    _500 = "500"
    _501 = "501"
    _502 = "502"
    _503 = "503"
    _504 = "504"
    _505 = "505"
    _506 = "506"
    _507 = "507"
    _508 = "508"
    _510 = "510"
    _511 = "511"

    allowable_values = [_100, _101, _102, _103, _200, _201, _202, _203, _204, _205, _206, _207, _208, _226, _300, _301, _302, _303, _304, _305, _306, _307, _308, _400, _401, _402, _403, _404, _405, _406, _407, _408, _409, _410, _411, _412, _413, _414, _415, _416, _417, _421, _422, _423, _424, _426, _428, _429, _431, _451, _500, _501, _502, _503, _504, _505, _506, _507, _508, _510, _511]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """HttpStatusCode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HttpStatusCode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HttpStatusCode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class AddSysStatisticConfigsInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'statistic_code': 'str',
        'statistic_name': 'str',
        'statistic_type': 'int',
        'statistic_var_ref_info': 'StatisticVarRefDto',
        'is_display': 'bool',
        'unit': 'str',
        'group_name': 'str'
    }

    attribute_map = {
        'statistic_code': 'statisticCode',
        'statistic_name': 'statisticName',
        'statistic_type': 'statisticType',
        'statistic_var_ref_info': 'statisticVarRefInfo',
        'is_display': 'isDisplay',
        'unit': 'unit',
        'group_name': 'groupName'
    }

    def __init__(self, statistic_code=None, statistic_name=None, statistic_type=None, statistic_var_ref_info=None, is_display=None, unit=None, group_name=None, local_vars_configuration=None):  # noqa: E501
        """AddSysStatisticConfigsInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._statistic_code = None
        self._statistic_name = None
        self._statistic_type = None
        self._statistic_var_ref_info = None
        self._is_display = None
        self._unit = None
        self._group_name = None
        self.discriminator = None

        self.statistic_code = statistic_code
        self.statistic_name = statistic_name
        self.statistic_type = statistic_type
        self.statistic_var_ref_info = statistic_var_ref_info
        self.is_display = is_display
        self.unit = unit
        self.group_name = group_name

    @property
    def statistic_code(self):
        """Gets the statistic_code of this AddSysStatisticConfigsInput.  # noqa: E501

        统计编码 statistic code  # noqa: E501

        :return: The statistic_code of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: str
        """
        return self._statistic_code

    @statistic_code.setter
    def statistic_code(self, statistic_code):
        """Sets the statistic_code of this AddSysStatisticConfigsInput.

        统计编码 statistic code  # noqa: E501

        :param statistic_code: The statistic_code of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and statistic_code is None:  # noqa: E501
            raise ValueError("Invalid value for `statistic_code`, must not be `None`")  # noqa: E501

        self._statistic_code = statistic_code

    @property
    def statistic_name(self):
        """Gets the statistic_name of this AddSysStatisticConfigsInput.  # noqa: E501

        统计名称 statistic name  # noqa: E501

        :return: The statistic_name of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: str
        """
        return self._statistic_name

    @statistic_name.setter
    def statistic_name(self, statistic_name):
        """Sets the statistic_name of this AddSysStatisticConfigsInput.

        统计名称 statistic name  # noqa: E501

        :param statistic_name: The statistic_name of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and statistic_name is None:  # noqa: E501
            raise ValueError("Invalid value for `statistic_name`, must not be `None`")  # noqa: E501

        self._statistic_name = statistic_name

    @property
    def statistic_type(self):
        """Gets the statistic_type of this AddSysStatisticConfigsInput.  # noqa: E501

        统计类型 statistic type  # noqa: E501

        :return: The statistic_type of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: int
        """
        return self._statistic_type

    @statistic_type.setter
    def statistic_type(self, statistic_type):
        """Sets the statistic_type of this AddSysStatisticConfigsInput.

        统计类型 statistic type  # noqa: E501

        :param statistic_type: The statistic_type of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and statistic_type is None:  # noqa: E501
            raise ValueError("Invalid value for `statistic_type`, must not be `None`")  # noqa: E501
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and statistic_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `statistic_type` ({0}), must be one of {1}"  # noqa: E501
                .format(statistic_type, allowed_values)
            )

        self._statistic_type = statistic_type

    @property
    def statistic_var_ref_info(self):
        """Gets the statistic_var_ref_info of this AddSysStatisticConfigsInput.  # noqa: E501


        :return: The statistic_var_ref_info of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: StatisticVarRefDto
        """
        return self._statistic_var_ref_info

    @statistic_var_ref_info.setter
    def statistic_var_ref_info(self, statistic_var_ref_info):
        """Sets the statistic_var_ref_info of this AddSysStatisticConfigsInput.


        :param statistic_var_ref_info: The statistic_var_ref_info of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: StatisticVarRefDto
        """
        if self.local_vars_configuration.client_side_validation and statistic_var_ref_info is None:  # noqa: E501
            raise ValueError("Invalid value for `statistic_var_ref_info`, must not be `None`")  # noqa: E501

        self._statistic_var_ref_info = statistic_var_ref_info

    @property
    def is_display(self):
        """Gets the is_display of this AddSysStatisticConfigsInput.  # noqa: E501

        是否展示该条统计信息 if display on the front end  # noqa: E501

        :return: The is_display of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_display

    @is_display.setter
    def is_display(self, is_display):
        """Sets the is_display of this AddSysStatisticConfigsInput.

        是否展示该条统计信息 if display on the front end  # noqa: E501

        :param is_display: The is_display of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_display is None:  # noqa: E501
            raise ValueError("Invalid value for `is_display`, must not be `None`")  # noqa: E501

        self._is_display = is_display

    @property
    def unit(self):
        """Gets the unit of this AddSysStatisticConfigsInput.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this AddSysStatisticConfigsInput.

        单位 unit  # noqa: E501

        :param unit: The unit of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and unit is None:  # noqa: E501
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501

        self._unit = unit

    @property
    def group_name(self):
        """Gets the group_name of this AddSysStatisticConfigsInput.  # noqa: E501

        统计分组 statistic group  # noqa: E501

        :return: The group_name of this AddSysStatisticConfigsInput.  # noqa: E501
        :rtype: str
        """
        return self._group_name

    @group_name.setter
    def group_name(self, group_name):
        """Sets the group_name of this AddSysStatisticConfigsInput.

        统计分组 statistic group  # noqa: E501

        :param group_name: The group_name of this AddSysStatisticConfigsInput.  # noqa: E501
        :type: str
        """

        self._group_name = group_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddSysStatisticConfigsInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddSysStatisticConfigsInput):
            return True

        return self.to_dict() != other.to_dict()
